@@ -38,12 +38,12 @@ if test "$DIE" -eq 1; then
   exit 1
 fi
 
-
-aclocal 						\
-&& echo "Running autoheader..."				\
-&& autoheader						\
-&& echo "Running automake --gnu --add-missing --ignore-deps ..."	\
-&& automake --gnu --add-missing --ignore-deps		\
-&& echo "Running autoconf ..."				\
-&& autoconf
+echo "Running aclocal ..." \
+&& aclocal --force	\
+&& echo "Running autoheader ..." \
+&& autoheader --force \
+&& echo "Running automake ..." \
+&& automake --gnu --add-missing --ignore-deps --copy \
+&& echo "Running autoconf ..." \
+&& autoconf --force
 
