@@ -1,4 +1,4 @@
-/* netToe Version 1.4.2
+/* netToe Version 1.5
  *
  * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
  *           2009-2013 Mats Erik Andersson <meand@users.sourceforge.net>
@@ -22,12 +22,6 @@
 #ifndef _MISC_H
 # define _MISC_H 1
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <time.h>
-
 void parse_cmd_args(int argc, char *argv[]);
 
 void get_player_pname(char * str, size_t maxlen);
