@@ -1,4 +1,4 @@
-/* netToe Version 1.4.1
+/* netToe Version 1.5
  *
  * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
  *           2009-2013 Mats Erik Andersson <meand@users.sourceforge.net>
@@ -20,24 +20,8 @@
 */
 
 #ifndef	_NETWORK_H
-#define _NETWORK_H 1
+# define _NETWORK_H 1
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-#include <stdio.h>
-#include <string.h> 
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <sys/wait.h>
-#include <netdb.h>
-
-                     
 extern int establish_listening_socket ( unsigned short port_number, char *peer_ip_address, int bytes);
 extern int connect_to_socket ( char *host_ip_number, unsigned short port_number );
 extern int write_to_socket ( int connected_socket, char *buffer, int bytes );
